==> fdowms-3.3.1.tar.gz: OpenSource_FDO/Providers/WMS/Managed/Src/OSGeo/FDO/Providers/WMS/mgIGetImageFormatsImp.cpp <==
/*
* 
* Copyright (C) 2004-2007  Autodesk, Inc.
* 
* This library is free software; you can redistribute it and/or
* modify it under the terms of version 2.1 of the GNU Lesser
* General Public License as published by the Free Software Foundation.
* 
* This library is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
* Lesser General Public License for more details.
* 
* You should have received a copy of the GNU Lesser General Public
* License along with this library; if not, write to the Free Software
* Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*
*/

#include "stdafx.h"
#include "WMS\IGetImageFormats.h"
#include "mgIGetImageFormats.h"
#include "mgIGetImageFormatsImp.h"

NAMESPACE_OSGEO_FDO_PROVIDERS_WMS::IGetImageFormatsImp::IGetImageFormatsImp(System::IntPtr unmanaged, System::Boolean autoDelete) : NAMESPACE_OSGEO_FDO_COMMANDS::ICommandImp(unmanaged, autoDelete)
{

}

FdoWmsIGetImagefromats* NAMESPACE_OSGEO_FDO_PROVIDERS_WMS::IGetImageFormatsImp::GetImpObj()
{
    return static_cast<FdoWmsIGetImagefromats*>(__super::UnmanagedObject.ToPointer());
}

NAMESPACE_OSGEO_COMMON::StringCollection* NAMESPACE_OSGEO_FDO_PROVIDERS_WMS::IGetImageFormatsImp::Execute()
{
    FdoStringCollection* result;
	EXCEPTION_HANDLER(result = GetImpObj()->Execute());
    return (new NAMESPACE_OSGEO_COMMON::StringCollection(result, true));
}

System::Void NAMESPACE_OSGEO_FDO_PROVIDERS_WMS::IGetImageFormatsImp::Dispose()
{
	NAMESPACE_OSGEO_RUNTIME::Disposable::Dispose();
}

==> fdowms-3.4.0.tar.gz: OpenSource_FDO/Providers/WMS/Managed/Src/OSGeo/FDO/Providers/WMS/mgIGetImageFormatsImp.cpp <==
/*
* 
* Copyright (C) 2004-2007  Autodesk, Inc.
* 
* This library is free software; you can redistribute it and/or
* modify it under the terms of version 2.1 of the GNU Lesser
* General Public License as published by the Free Software Foundation.
* 
* This library is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
* Lesser General Public License for more details.
* 
* You should have received a copy of the GNU Lesser General Public
* License along with this library; if not, write to the Free Software
* Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*
*/

#include "stdafx.h"
#include "WMS\IGetImageFormats.h"
#include "mgIGetImageFormats.h"
#include "mgIGetImageFormatsImp.h"

NAMESPACE_OSGEO_FDO_PROVIDERS_WMS::GetImageFormatsCommand::GetImageFormatsCommand(NAMESPACE_OSGEO_FDO_COMMANDS::ICommand* command, System::Boolean autoDelete) : NAMESPACE_OSGEO_FDO_COMMANDS::ICommandImp(command, autoDelete)
{
}

NAMESPACE_OSGEO_FDO_PROVIDERS_WMS::GetImageFormatsCommand::GetImageFormatsCommand(System::IntPtr unmanaged, System::Boolean autoDelete) : NAMESPACE_OSGEO_FDO_COMMANDS::ICommandImp(unmanaged, autoDelete)
{
}

FdoWmsIGetImagefromats* NAMESPACE_OSGEO_FDO_PROVIDERS_WMS::GetImageFormatsCommand::GetImpObj()
{
    return static_cast<FdoWmsIGetImagefromats*>(__super::UnmanagedObject.ToPointer());
}

NAMESPACE_OSGEO_COMMON::StringCollection* NAMESPACE_OSGEO_FDO_PROVIDERS_WMS::GetImageFormatsCommand::Execute()
{
    FdoStringCollection* result;
	EXCEPTION_HANDLER(result = GetImpObj()->Execute());
    return (new NAMESPACE_OSGEO_COMMON::StringCollection(result, true));
}
